@@ -3,15 +3,15 @@ use tokio::{net::UnixListener, signal};
 
 #[tokio::main]
 async fn main() {
-    let config = Default::default();
+    let listener = UnixListener::bind("/run/ipmilter.sock")
+        .expect("cannot open milter socket");
 
     let callbacks = Callbacks::new()
         .on_connect(|context, _, socket_info| {
             Box::pin(handle_connect(context, socket_info))
         });
 
-    let listener = UnixListener::bind("/run/ipmilter.sock")
-        .expect("cannot open milter socket");
+    let config = Default::default();
 
     indymilter::run(listener, callbacks, config, signal::ctrl_c())
         .await
@@ -20,9 +20,9 @@ async fn main() {
 
 async fn handle_connect(
     _: &mut Context<()>,
-    socket_info: Option<SocketInfo>,
+    socket_info: SocketInfo,
 ) -> Status {
-    if let Some(SocketInfo::Inet(addr)) = socket_info {
+    if let SocketInfo::Inet(addr) = socket_info {
         println!("connect from {}", addr.ip());
     }
 
