@@ -74,10 +74,10 @@ where
     }
 }
 
-// A connection can be cloned. This means that cloned connections all carry a
-// handle to the message-processing task (actor) holding the actual connection
-// stream. Once the last `Connection` is dropped, so is the `mpsc::Sender`
-// handle and the task then exits.
+// A connection can be cloned. Cloned connections all carry a handle to the
+// message-processing task (actor) holding the actual connection stream. Once
+// the last `Connection` is dropped, so is the `mpsc::Sender` handle and the
+// task then exits.
 //
 // Note that in a milter session, a connection is only ever read from or written
 // to serially. However, during the eom stage, a clone of the connection is used
@@ -96,8 +96,7 @@ impl Connection {
 
         // Creating a `Connection` spawns a task that processes requests for as
         // long as the connection (or a clone) exists. When the last
-        // `mpsc::Sender` held by a connection is dropped the call on `recv`
-        // will return and the task exits.
+        // `mpsc::Sender` held by a connection is dropped, the task exits.
 
         // The stream handler takes exclusive ownership of the stream, and is
         // handed off directly to `tokio::spawn`, becoming an *actor* solely
@@ -159,10 +158,7 @@ impl Connection {
 mod tests {
     use super::*;
     use std::io::ErrorKind;
-    use tokio::{
-        io::{AsyncReadExt, AsyncWriteExt},
-        join, time,
-    };
+    use tokio::{io::AsyncReadExt, join};
 
     #[tokio::test]
     async fn multiple_connections() {
@@ -210,9 +206,9 @@ mod tests {
         let conn = Connection::new(stream, timeout);
 
         // Both the `Connection` and the client end of the duplex stream are
-        // moved into the futures. Connection therefore is dropped and closes
-        // after 30 seconds. The client write then fails as it attempts to write
-        // a few seconds later.
+        // moved into the futures. The connection is therefore dropped and
+        // closes after 30 seconds. The client write then fails as it attempts
+        // to write a few seconds later.
 
         time::pause();
 
