@@ -386,7 +386,7 @@ impl SetErrorReply for SmtpReply {
         // Like in libmilter, compatibility of reply code and enhanced status
         // code is not checked.
 
-        let mut message_lines = Vec::new();
+        let mut msg_lines = Vec::new();
 
         for (i, line) in message.into_iter().enumerate() {
             if i >= 32 {
@@ -402,13 +402,13 @@ impl SetErrorReply for SmtpReply {
                 return Err(SmtpReplyError::InvalidReplyText);
             }
 
-            message_lines.push(line);
+            msg_lines.push(line);
         }
 
         self.error_reply = Some(ErrorReply {
             rcode,
             xcode,
-            message: message_lines,
+            message: msg_lines,
         });
 
         Ok(())
@@ -472,7 +472,7 @@ impl ErrorReply {
             }
         };
 
-        CString::new(msg).expect("ill-formed error reply text")
+        CString::new(msg).expect("invalid error reply text")
     }
 }
 
