@@ -4,23 +4,27 @@ mod common;
 
 pub use crate::common::*;
 use byte_strings::c_str;
-use indymilter::{Callbacks, Context, ContextActions, SocketInfo, Status};
-use std::ffi::CString;
+use indymilter::{Callbacks, ContextActions, Status};
 use tracing::info;
 
 #[tokio::test]
-async fn basic_miltertest() {
+async fn basic_stages() {
     init_tracing_subscriber();
 
-    let callbacks = Callbacks::new()
-        .on_negotiate(|_cx, actions, opts| {
+    let callbacks = Callbacks::<()>::new()
+        .on_negotiate(|_, actions, opts| {
             Box::pin(async move {
                 info!(?actions, ?opts, "inside negotiate callback");
+                Status::AllOpts
+            })
+        })
+        .on_connect(|_, hostname, socket_info| {
+            Box::pin(async move {
+                info!(?hostname, ?socket_info, "inside connect callback");
                 Status::Continue
             })
         })
-        .on_connect(|cx, hostname, addr| Box::pin(connect_callback(cx, hostname, addr)))
-        .on_helo(|_cx, hostname| {
+        .on_helo(|_, hostname| {
             Box::pin(async move {
                 info!(?hostname, "inside helo callback");
                 Status::Continue
@@ -29,20 +33,21 @@ async fn basic_miltertest() {
         .on_eom(|cx| {
             Box::pin(async move {
                 info!("inside eom callback");
-                cx.actions.add_header("name", "value").await.unwrap();
+
+                cx.actions.add_header("name1", "value1").await.unwrap();
                 cx.actions.add_header("name2", "value2").await.unwrap();
 
                 Status::Continue
             })
         })
-        .on_close(|_cx| {
+        .on_close(|_| {
             Box::pin(async move {
                 info!("inside close callback");
                 Status::Continue
             })
         });
 
-    let milter = Milter::spawn(LOCALHOST, callbacks, Default::default())
+    let milter = Milter::spawn(LOCALHOST, callbacks, default_config())
         .await
         .unwrap();
 
@@ -55,22 +60,17 @@ async fn basic_miltertest() {
     assert!(exit_code.success());
 }
 
-async fn connect_callback(_: &mut Context<()>, hostname: CString, addr: SocketInfo) -> Status {
-    info!(?hostname, ?addr, "inside connect callback");
-
-    Status::Continue
-}
-
 #[tokio::test]
-async fn basic_milter_macros() {
+async fn eoh_eom_macros() {
     init_tracing_subscriber();
 
     let callbacks = Callbacks::<()>::new()
         .on_eoh(|_| Box::pin(async { Status::Continue }))
         .on_eom(|cx| {
             Box::pin(async move {
-                if let Some(x) = cx.macros.get(c_str!("{name}")) {
-                    if x.to_string_lossy() == "5678" {
+                // Make sure `eoh`/`eom` macros are stored in the right order.
+                if let Some(name) = cx.macros.get(c_str!("{name}")) {
+                    if name.to_string_lossy() == "5678" {
                         return Status::Continue;
                     }
                 }
@@ -78,7 +78,7 @@ async fn basic_milter_macros() {
             })
         });
 
-    let milter = Milter::spawn(LOCALHOST, callbacks, Default::default())
+    let milter = Milter::spawn(LOCALHOST, callbacks, default_config())
         .await
         .unwrap();
 
